import re
from dosage.modules.helpers.BasicComicModule import BasicComicModule

class AppleGeeks(BasicComicModule):
    latestUrl = 'http://www.applegeeks.com/'
    imageUrl = 'http://www.applegeeks.com/index.php?comic=%s'
    imageSearch = re.compile(r'<img src="(/comics/issue\d+?\..+?)"', re.IGNORECASE)
    prevSearch = re.compile(r'<a href="(index.php\?comic=\d+)">Previous', re.IGNORECASE)
    help = 'Index format: n (unpadded)'
